# CLA Check

Check to see if a contributor with a specific email address has signed
Canonical's Contributor License Agreement.

## How to install

This is packaged as a snap:

    $ sudo snap install cla-check

## How to use

It's super easy to run:

    $ cla-check <email address>
